package net.knarcraft.launchpad.config;

import net.knarcraft.knarlib.formatting.TranslatableMessage;

/**
 * A message which ca be displayed to the user
 */
public enum LaunchpadMessage implements TranslatableMessage {

    /* ************** *
     * Error messages *
     * ************** */

    /**
     * The message displayed if the console tries to execute a player-only command
     */
    ERROR_PLAYER_ONLY,

    /**
     * The message displayed if the player tries to modify launchpad property for a block outside the whitelist
     */
    ERROR_NOT_WHITELISTED,

    /* **************** *
     * Success messages *
     * **************** */

    /**
     * The message displayed if the Launchpad plugin is reloaded
     */
    SUCCESS_PLUGIN_RELOADED,

    /**
     * The message to display when a player uses /launchpad clear
     */
    SUCCESS_MODIFICATIONS_CLEARED,

    /**
     * The message to display to prompt the player to click a launchpad
     */
    SUCCESS_CLICK_BLOCK,

    /**
     * The message to display when a launchpad has been added or modified
     */
    SUCCESS_MODIFIED_LAUNCHPAD,

    /**
     * The message to display when the player is not looking at a block, which is required
     */
    ERROR_NOT_LOOKING_AT_BLOCK,

    /**
     * The message to display when the player is not looking at a launchpad
     */
    ERROR_NO_LAUNCHPAD,

    /**
     * The format to use for printing launchpad information
     */
    SUCCESS_LAUNCHPAD_INFO,

    /**
     * The suffix to add when a launchpad's value is inherited
     */
    SUCCESS_LAUNCHPAD_INFO_INHERITED,
    ;

    @Override
    public TranslatableMessage[] getAllMessages() {
        return LaunchpadMessage.values();
    }

}
